==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/RefreshCompletedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { RefreshCompletedEventArgsDescription } from "./RefreshCompletedEventArgsDescription";
/**
 * @hidden
 */
var RefreshCompletedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(RefreshCompletedEventArgsDescriptionMetadata, _super);
    function RefreshCompletedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    RefreshCompletedEventArgsDescriptionMetadata.b = function (a) {
        if (RefreshCompletedEventArgsDescriptionMetadata.a == null) {
            RefreshCompletedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            RefreshCompletedEventArgsDescriptionMetadata.c(RefreshCompletedEventArgsDescriptionMetadata.a);
        }
        if (a.g(RefreshCompletedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(RefreshCompletedEventArgsDescriptionMetadata.a);
    };
    RefreshCompletedEventArgsDescriptionMetadata.c = function (a) {
    };
    RefreshCompletedEventArgsDescriptionMetadata.d = function (a) {
        RefreshCompletedEventArgsDescriptionMetadata.b(a);
        a.u("RefreshCompletedEventArgs", function () { return new RefreshCompletedEventArgsDescription(); });
        a.t("RefreshCompletedEventArgs", RefreshCompletedEventArgsDescriptionMetadata.a);
    };
    RefreshCompletedEventArgsDescriptionMetadata.$t = markType(RefreshCompletedEventArgsDescriptionMetadata, 'RefreshCompletedEventArgsDescriptionMetadata');
    RefreshCompletedEventArgsDescriptionMetadata.a = null;
    return RefreshCompletedEventArgsDescriptionMetadata;
}(Base));
export { RefreshCompletedEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/RefreshCompletedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { RefreshCompletedEventArgsDescription } from "./RefreshCompletedEventArgsDescription";
/**
 * @hidden
 */
var RefreshCompletedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(RefreshCompletedEventArgsDescriptionMetadata, _super);
    function RefreshCompletedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    RefreshCompletedEventArgsDescriptionMetadata.b = function (a) {
        if (RefreshCompletedEventArgsDescriptionMetadata.a == null) {
            RefreshCompletedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            RefreshCompletedEventArgsDescriptionMetadata.c(RefreshCompletedEventArgsDescriptionMetadata.a);
        }
        if (a.j(RefreshCompletedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(RefreshCompletedEventArgsDescriptionMetadata.a);
    };
    RefreshCompletedEventArgsDescriptionMetadata.c = function (a) {
    };
    RefreshCompletedEventArgsDescriptionMetadata.d = function (a) {
        RefreshCompletedEventArgsDescriptionMetadata.b(a);
        a.aa("RefreshCompletedEventArgs", function () { return new RefreshCompletedEventArgsDescription(); });
        a.z("RefreshCompletedEventArgs", RefreshCompletedEventArgsDescriptionMetadata.a);
    };
    RefreshCompletedEventArgsDescriptionMetadata.$t = markType(RefreshCompletedEventArgsDescriptionMetadata, 'RefreshCompletedEventArgsDescriptionMetadata');
    RefreshCompletedEventArgsDescriptionMetadata.a = null;
    return RefreshCompletedEventArgsDescriptionMetadata;
}(Base));
export { RefreshCompletedEventArgsDescriptionMetadata };
